#
# spec file for package kmod
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kmod
%define lname	libkmod2
Summary:        Utilities to load modules into the kernel
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
Group:          System/Kernel
Version:        17
Release:        19.1
Url:            http://www.jonmasters.org/blog/2011/12/20/libkmod-replaces-module-init-tools/
#Announce:	https://lwn.net/Articles/577962/

#Git-Web:	http://git.kernel.org/?p=utils/kernel/kmod/kmod.git;a=summary
#Git-Clone:	git://git.kernel.org/pub/scm/utils/kernel/kmod/kmod
Source:         ftp://ftp.kernel.org/pub/linux/utils/kernel/kmod/%name-%version.tar.xz
Source2:        ftp://ftp.kernel.org/pub/linux/utils/kernel/kmod/%name-%version.tar.sign
Patch2:         0002-modprobe-Recognize-allow-unsupported-modules-on-comm.patch
Patch3:         0003-libkmod-config-Recognize-allow_unsupported_modules-i.patch
Patch8:         depmod-Ignore_PowerPC64_ABIv2_.TOC.symbol.patch
Patch9:         0009-libkmod-Implement-filtering-of-unsupported-modules-o.patch
Patch10:        0010-modprobe-Implement-allow-unsupported-modules.patch
Patch16:        0001-Do-not-filter-unsupported-modules-when-running-a-van.patch
Patch17:        0001-libkmod-Handle-long-lines-in-proc-modules.patch
Patch18:        0001-Fix-race-while-loading-modules.patch
Patch19:        depmod-Don-t-add-.TOC.-when-it-s-in-the-kernel.patch
Patch20:        depmod-Prevent-module-dependency-files-missing-durin.patch
Patch21:        depmod-Prevent-module-dependency-files-corruption-du.patch
Patch22:        depmod-shut-up-gcc-insufficinet-buffer-warning.patch
Patch23:        kmod-build-cure-compiler-warnings-showing-up-externa.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig >= 0.21
BuildRequires:  xz
Requires:       suse-module-tools

%description
kmod is a set of tools to handle common tasks with Linux kernel
modules like insert, remove, list, check properties, resolve
dependencies and aliases.

These tools are designed on top of libkmod, a library that is shipped
with kmod. The aim is to be compatible with tools, configurations and
indexes from module-init-tools project.

%package compat
Summary:        Compat symlinks for kernel module utilities
License:        GPL-2.0-or-later
Group:          System/Kernel
Requires:       kmod
Obsoletes:      module-init-tools < 3.16
Provides:       module-init-tools = 3.16
Provides:       modutils

%description compat
kmod is a set of tools to handle common tasks with Linux kernel
modules like insert, remove, list, check properties, resolve
dependencies and aliases.

This package contains traditional name symlinks (lsmod, etc.)

%package -n %lname
Summary:        Library to interact with Linux kernel modules
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n %lname
libkmod was created to allow programs to easily insert, remove and
list modules, also checking its properties, dependencies and aliases.

%package -n libkmod-devel
Summary:        Development files for libkmod
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %{version}

%description -n libkmod-devel
libkmod was created to allow programs to easily insert, remove and
list modules, also checking its properties, dependencies and aliases.

This package contains the development headers for the library found
in %lname.

%prep
%{?gpg_verify: xz -dk "%{S:0}"; %gpg_verify %{S:2}}
%setup -q
%autopatch -p1

%build
autoreconf -fi
# The extra --includedir gives us the possibility to detect dependent
# packages which fail to properly use pkgconfig.
%configure \
	--without-xz \
	--without-zlib \
	--includedir="%_includedir/kmod-%version" \
	--with-rootlibdir="%_libdir" \
	--bindir="%_bindir"
make %{?_smp_mflags}

%install
b="%buildroot";
make install DESTDIR="$b";
rm -f "$b/%_libdir"/*.la

mkdir -p "$b/%_libexecdir/kmod" "$b/%_sbindir" "$b/sbin";
for i in depmod insmod lsmod modinfo modprobe rmmod; do
	#
	# kmod-compat and kmod-compat(usrmerge)
	#
	ln -s "%_bindir/kmod" "$b/%_sbindir/$i";
	ln -s "%_bindir/kmod" "$b/sbin/$i";

	#
	# Make symlinks also available in normal fashion,
	# so one can actually run it.
	#
	ln -s "%_bindir/kmod" "$b/%_libexecdir/kmod/$i";
done;
mkdir -p "$b/%_bindir" "$b/bin";
for i in lsmod; do
	ln -s "%_bindir/kmod" "$b/%_bindir/$i";
	ln -s "%_bindir/kmod" "$b/bin/$i";
done;

#
# make mkinitrd happy
# (last time checked it does not look into /usr)
#
mkdir -p "$b"/{bin,sbin,%_lib};
ln -s "%_bindir/kmod" "$b/bin/";
%if "%_libdir" != "/%_lib"
ln -s "%_libdir/libkmod.so.2" "$b/%_lib/";
ln -s "%_libdir/libkmod.so.2.2.7" "$b/%_lib/";
%endif

%check
make check

%post
%{?regenerate_initrd_post}

%posttrans
%{?regenerate_initrd_posttrans}

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files
%defattr(-,root,root)
%_bindir/kmod
%_libexecdir/kmod
/bin/kmod
%_datadir/bash-completion/

%files -n %lname
%defattr(-,root,root)
%_libdir/libkmod.so.2*
/%_lib/libkmod.so.2*

%files -n libkmod-devel
%defattr(-,root,root)
%_includedir/*
%_libdir/pkgconfig/libkmod.pc
%_libdir/libkmod.so

%files compat
%defattr(-,root,root)
%_bindir/lsmod
%_sbindir/depmod
%_sbindir/insmod
%_sbindir/lsmod
%_sbindir/modinfo
%_sbindir/modprobe
%_sbindir/rmmod
# UsrMerge
/bin/lsmod
/sbin/depmod
/sbin/insmod
/sbin/lsmod
/sbin/modinfo
/sbin/modprobe
/sbin/rmmod
# EndUsrMerge
%_mandir/man5/depmod.d.5*
%_mandir/man5/modprobe.d.5*
%_mandir/man5/modules.dep.5*
%_mandir/man5/modules.dep.bin.5*
%_mandir/man8/depmod.8*
%_mandir/man8/insmod.8*
%_mandir/man8/lsmod.8*
%_mandir/man8/modinfo.8*
%_mandir/man8/modprobe.8*
%_mandir/man8/rmmod.8*

%changelog
* Thu Apr 25 2019 Michal Suchanek <msuchanek@suse.de>
- Fix warming in libkmod.h (boo#1097869).
  kmod-build-cure-compiler-warnings-showing-up-externa.patch
- Prevent potential buffer overflow in libkmod (bsc#1118629).
  depmod-shut-up-gcc-insufficinet-buffer-warning.patch
* Fri Dec  7 2018 Michal Suchanek <msuchanek@suse.de>
- Fix module dependency file corruption on parallel invocation (bsc#1118629).
  depmod-Prevent-module-dependency-files-corruption-du.patch
  depmod-Prevent-module-dependency-files-missing-durin.patch
* Thu Dec  7 2017 msuchanek@suse.com
- Fix resolving .TOC. in modules on 4.4 and older kernel (bsc#1070209)
  depmod-Don-t-add-.TOC.-when-it-s-in-the-kernel.patch
* Wed Nov  9 2016 martin.wilck@suse.com
- Fix race while loading modules (bsc#998906)
  * Add 0001-Fix-race-while-loading-modules.patch (upstream fd44a98)
* Thu Jul 21 2016 mmarek@suse.com
- Regenerate initrd on kmod update (bsc#989788)
- Sync specfile with openSUSE:Factory
* Fri Jun 17 2016 mmarek@suse.cz
- libkmod: Handle long lines in /proc/modules (bsc#983754)
  0001-libkmod-Handle-long-lines-in-proc-modules.patch
* Tue Feb  9 2016 dvaleev@suse.com
- Fix kernel master build for ppc64le (bsc#1070209)
  depmod-Ignore_PowerPC64_ABIv2_.TOC.symbol.patch
* Fri May 16 2014 mmarek@suse.cz
- Updated to kmod 17
  * Do not require xsltproc for build
  * Parse softdeps stored in kernel modules
  * Add experimental python bindings (not enabled in the package yet)
  * Misc bugfixes
- Deleted patches that went upstream. Only the unsupported modules
  feature remains:
  0002-modprobe-Recognize-allow-unsupported-modules-on-comm.patch
  0003-libkmod-config-Recognize-allow_unsupported_modules-i.patch
  0009-libkmod-Implement-filtering-of-unsupported-modules-o.patch
  0010-modprobe-Implement-allow-unsupported-modules.patch
  0001-Do-not-filter-unsupported-modules-when-running-a-van.patch
* Fri Apr 11 2014 mmarek@suse.cz
- testsutie: Uncompress most modules (updated test-files.tar.xz)
- testsuite: Do not run tests with *.ko.gz if zlib is not enabled
- Disable compression support, as other tools do not support it
  (e.g. module signing)
* Fri Apr  4 2014 mmarek@suse.cz
- Do not filter unsupported modules when running a vanilla kernel
  (bnc#871066)
* Tue Apr  1 2014 mmarek@suse.cz
- libkmod: Ignore errors from softdeps (bnc#831227)
- config: also parse softdeps from modules (bnc#831227)
* Mon Mar 31 2014 mmarek@suse.cz
- libkmod-config,depmod: Accept special files as configuration
  files, too
- libkmod-config: Only match dot before '=' in /proc/cmdline
* Tue Mar 11 2014 mmarek@suse.cz
- Provide and obsolete module-init-tools (bnc#867442)
* Fri Mar  7 2014 mmarek@suse.cz
- testsuite: Fix uname() during glibc startup
* Wed Mar  5 2014 mmarek@suse.cz
- testsuite: Check the list of loaded modules after a test
- testsuite: Add test for modprobe --force
- testsuite: Do not provide finit_module(2) on older kernels
- Add some tests for kernels without finit_module(2)
- libkmod-module: Simplify kmod_module_insert_module()
- libkmod: Implement filtering of unsupported modules (fate#316971)
- modprobe: Implement --allow-unsupported-modules (fate#316971)
- make the %%check section fatal
* Wed Feb 26 2014 mmarek@suse.cz
- Remove "rmmod -w" documentation and getopt entry
- modprobe: Recognize --allow-unsupported-modules on commandline
  (fate#316971)
- libkmod-config: Recognize allow_unsupported_modules in the
  configuration (fate#316971)
* Wed Feb 26 2014 mmarek@suse.cz
- Drop the non-upstream kmod-no-static.diff; the size difference is
  negligible.
* Tue Jan  7 2014 jengelh@inai.de
- Update to new upstream release 16
  * The option to wait on module removal has been removed from the
  kernel, and now from rmmod. The constant KMOD_REMOVE_NOWAIT in
  libkmod is still there for backwards compatibility but it is
  always enforced, passing O_NONBLOCK to delete_module(2).
* Mon Sep  2 2013 jengelh@inai.de
- Update to new upstream release 15
  * kmod static-nodes no longer fails if modules.devname does not exist
  * Fix getting boolean parameter from kernel cmdline in case the
  value is omitted
  * kmod static-nodes creates parent directories if given a -o option
- Add kmod-no-static.diff
* Wed Jul  3 2013 jengelh@inai.de
- Update to new upstream release 14
  * Some bug fixes and a new "static-nodes" command to parse
  modules.devname.
* Mon Apr 15 2013 crrodriguez@opensuse.org
- Update to new upstream release 13
  * depmod: --symbol-prefix actually requires an argument
  * depmod: fix builtin symbols resolution when the prefix symbol is set
  * libkmod: Use secure_getenv if available
  * rmmod: Teach rmmod about builtin modules
  * libkmod: add finit_module logic
  * modprobe: Fix assertion on --show-depends with bogus config file
  * Many other bugfixes see https://lwn.net/Articles/546711
* Thu Dec  6 2012 jengelh@inai.de
- Update to new upstream release 12
  * Fix removing vermagic from module when told to force load a module
  * Fix removing __versions section when told to force load a
  module: we need to mangle the section header, not the section.
  * modinfo no longer fails while loading a module from file when
  path contains ".ko" substring
* Fri Nov 23 2012 jengelh@inai.de
- Require suse-module-tools now that it is present in Base:System
- kmod-compat depends on kmod, add that missing Requires.
* Sat Nov 10 2012 hrvoje.senjan@gmail.com
- Update to kmod-11
  * Fix testsuite defining symbols twice on 32 bit systems
  * Allow to check generated files against correct ones
  * libkmod now keeps a file opened after the first call to
  * kmod_module_get_{info,versions,symbols,dependency_symbols}. This
  reduces signficantly the amount of time depmod tool takes to
  execute. Particularly if compressed modules are used.
  * Remove --with-rootprefix from build system. It was not a great
  idea after all and should not be use since it causes more harm
  than benefits.
  * Hide --wait option on rmmod. This feature is being targeted for
  removal from kernel. rmmod still accepts this option, but it is
  hidden now: man page and usage() says nothing about it and if
  it is used, user will get a 10s sleep. This way we can check and
  help if anyone is using this feature.
  * Refactor message logging on all tools, giving proper prefix,
  routing everything to syslog when asked for, etc.
  * Fix parsing of modules.order when using compressed modules
  * Usage messages go to stdout instead of stderr
  * Fix memory leak in hash implementation
* Thu Sep 13 2012 jengelh@inai.de
- Provide the "modutils" virtual symbol
- Update to new upstream release 10
  * Read coresize from /sys if supported
  * Add flag to kmod_module_probe_insert() to apply blacklisting
  during probe only if mod is an alias. Now modprobe uses this
  flag by default.
* Wed Jun 20 2012 rmilasan@suse.com
- Update to new upstream release 9
  * build-sys: allow compressed modules in testsuite
  * build-sys: Make dirs writable on rootfs creation
  * depmod: use ferror and fclose to check for error
  * depmod: return error when index is truncated due to ENOSPC
  * depmod: fix coding-style issue in array declaration
  * depmod: fail if any index could not be created
  * depmod: don't return error if modules.builtin don't exist
  * libkmod-util: split function for usec conversion
  * libkmod-util: add missing stdbool.h include
- Fix broken testsuites on 32bit systems.
  add: fix-32bits.diff
* Sat Apr 21 2012 jengelh@medozas.de
- Restore patch descriptions
  (and use `quilt setup` for rediff in future)
* Thu Apr 19 2012 rmilasan@suse.com
- Update to new upstream release 8
  * doc: remove links to NULL going nowhere.
  * modprobe: handle -ENOENT return from init_module.
  * doc: silent man page generation and fix gtk-doc warnings.
  * modprobe: fix typo in config dump: option->options.
* Wed Apr 18 2012 rmilasan@suse.com
- Update to new upstream release 7
  * build-sys: don't set CFLAGS and LDFLAGS.
  * build-sys: re-organize configure.ac.
  * configure.ac: Move link only flags out of CFLAGS and into LDFLAGS.
  * Add CC_CHECK_LDFLAGS_APPEND m4 macro.
  * config: use order /etc, /run, /lib.
  * modprobe: set log prio to 0 if user passed -q arg.
  * modprobe: always try to remove all modules in command line.
  * modprobe: don't check if module builtin to decide if it's builtin.
  * modprobe: fix error path in removing modules.
* Sat Mar 10 2012 rschweikert@suse.com
- place binary in /usr tree (UsrMerge project)
* Sat Mar  3 2012 jengelh@medozas.de
- Update to new upstream release 6
  * New API: kmod_module_apply_filter, a function to apply filters
  in a list of modules
  * Lookup modules.builtin.bin to decide if a module is built into
  the kernel
  * Resolve infinite loops with softdeps and user configs with
  install commands
* Tue Feb  7 2012 jengelh@medozas.de
- Update to new upstream release 5
  * modprobe no longer works with paths: it only accepts module names
  and/or aliases now. More code is now shared by libkmod and
  modprobe.
* Fri Jan 20 2012 jengelh@medozas.de
- Update to new upstream release 4
  * new APIs in libkmod: blacklists, install/remove commands,
  aliases, options, softdeps and dumping indexes
* Fri Jan  6 2012 jengelh@medozas.de
- Update to new upstream release 3
  * new APIs in libkmod: get symbols from module, parsing the ELF
  section, dependency symbols, insert module like modprobe
  * support for Xz-compressed modules
  * the depmod tool
* Sat Dec 24 2011 crrodriguez@opensuse.org
- Use --enable-zlib and buildRequire zlib
- run make check
* Sun Dec 18 2011 jengelh@medozas.de
- Initial package for build.opensuse.org
